@@ -148,15 +148,10 @@ hc_draw_shadow(GtkStyle * style,
 	ge_cairo_set_color(canvas, &foreground);
 	cairo_set_line_cap(canvas, CAIRO_LINE_CAP_BUTT);
 
-	/* Pixel Alignedness -
-			
-		If even line width, + 1.0 
-		If odd line width,  + 0.5 
-	 */
-	cairo_set_line_width (canvas, line_width + ((line_width%2)?1.0:0.5));
-
-	/* Stroke Rectangle */
-	ge_cairo_stroke_rectangle (canvas, x, y, width, height);
+	cairo_set_line_width (canvas, line_width);
+	ge_cairo_inner_rectangle (canvas, x, y, width, height);
+	
+	cairo_stroke(canvas);
 
 	cairo_destroy(canvas);
 }
@@ -200,10 +195,10 @@ hc_draw_shadow_gap (GtkStyle       *style,
 	/***********************************************/
 	line_width = HC_STYLE(style)->edge_thickness;
 
-	if (gap_size > 0)
+	if (CHECK_DETAIL (detail, "notebook"))
 	{
-		gap_pos += floor(line_width/2.0) + 1; 
-		gap_size -= (floor(line_width/2.0) + 1)*2;
+		gap_pos += line_width;
+		gap_size -= 2*line_width;
 	}
 
 	/***********************************************/
@@ -219,15 +214,10 @@ hc_draw_shadow_gap (GtkStyle       *style,
 	ge_cairo_set_color(canvas, foreground);
 	cairo_set_line_cap(canvas, CAIRO_LINE_CAP_BUTT);
 
-	/* Pixel Alignedness -
-			
-		If even line width, + 1.0 
-		If odd line width,  + 0.5 
-	 */
-	cairo_set_line_width (canvas, line_width + ((line_width%2)?1.0:0.5));
-
-	/* Stroke Rectangle */
-	ge_cairo_stroke_rectangle (canvas, x, y, width, height);
+	cairo_set_line_width (canvas, line_width);
+	ge_cairo_inner_rectangle (canvas, x, y, width, height);
+	
+	cairo_stroke(canvas);
 
 	cairo_destroy(canvas);
 }
@@ -364,15 +354,10 @@ hc_draw_extension (GtkStyle       *style,
 	ge_cairo_set_color(canvas, foreground);
 	cairo_set_line_cap(canvas, CAIRO_LINE_CAP_BUTT);
 
-	/* Pixel Alignedness -
-			
-		If even line width, + 1.0 
-		If odd line width,  + 0.5 
-	 */
-	cairo_set_line_width (canvas, line_width + ((line_width%2)?1.0:0.5));
-
-	/* Stroke Rectangle */
-	ge_cairo_stroke_rectangle (canvas, x, y, width, height);
+	cairo_set_line_width (canvas, line_width);
+	ge_cairo_inner_rectangle (canvas, x, y, width, height);
+	
+	cairo_stroke(canvas);
 
 	cairo_destroy(canvas);
 }
@@ -394,11 +379,17 @@ hc_draw_flat_box (GtkStyle	*style,
                   gint		 height)
 {
 	if (detail && !strcmp ("tooltip", detail))
+	{
 		hc_draw_box (style, window, state_type, shadow_type, area,
 				widget, detail, x, y, width, height);
+	}
 	else
+	{
+		GtkStyleClass *hc_parent_class;
+		hc_parent_class = GTK_STYLE_CLASS (g_type_class_peek_parent (G_OBJECT_GET_CLASS(style)));
 		hc_parent_class->draw_flat_box (style, window, state_type, shadow_type, area,
 							widget, detail, x, y, width, height);
+	}
 }
 
 
@@ -483,9 +474,9 @@ hc_draw_box_gap (GtkStyle       *style,
 	/* Draw Fill                                   */
 	/***********************************************/
 	gtk_style_apply_default_background (style, window,
-        					widget && !GTK_WIDGET_NO_WINDOW (widget),
-						state_type, area, x, y, width, height);
-  
+	                                    widget && !GTK_WIDGET_NO_WINDOW (widget),
+	                                    state_type, area, x, y, width, height);
+
 
 	/***********************************************/
 	/* Draw Border                                 */
@@ -541,7 +532,7 @@ hc_draw_handle (GtkStyle      *style,
 		/* we want to ignore the shadow border in paned widgets */
 		xthick = 0;
 		ythick = 0;
-	}  
+	}
 
 	clip_x = x + xthick;
 	clip_y = y + ythick;
@@ -554,13 +545,13 @@ hc_draw_handle (GtkStyle      *style,
 	/***********************************************/
 	hc_draw_box (style, window, state_type, shadow_type, area, widget, 
 			detail, x, y, width, height);
-  
-  
+
+
 	/***********************************************/
 	/* Draw Grip                                   */
 	/***********************************************/
 	hc_style = HC_STYLE (style);
-  
+
 	light = &hc_style->color_cube.light[state_type];
 	dark = &hc_style->color_cube.dark[state_type];
 
@@ -639,9 +630,9 @@ hc_draw_slider (GtkStyle * style,
 		{
 			do_hc_draw_line (canvas, &HC_STYLE(style)->color_cube.fg[state_type],
 						line_width /2, 
-						x + ceil(width/2) + 0.5, 
+						x + ceil(width/2.0) + 0.5, 
 						y + line_width, 
-						x + ceil(width/2) + 0.5, 
+						x + ceil(width/2.0) + 0.5, 
 						y + height - line_width);     
 		}
 		else
@@ -649,9 +640,9 @@ hc_draw_slider (GtkStyle * style,
 			do_hc_draw_line (canvas, &HC_STYLE(style)->color_cube.fg[state_type],
 						line_width /2, 
 						x + line_width, 
-						y + ceil(height/2) + 0.5,
+						y + ceil(height/2.0) + 0.5,
 						x + width - line_width, 
-						y + ceil(height/2) + 0.5);     
+						y + ceil(height/2.0) + 0.5);     
 		}
 	}
 
@@ -692,7 +683,7 @@ hc_draw_check (GtkStyle      *style,
 	
 	inconsistent = (shadow_type == GTK_SHADOW_ETCHED_IN);
 
-	line_width = ceil(HC_STYLE(style)->edge_thickness/2);
+	line_width = ceil(HC_STYLE(style)->edge_thickness/2.0);
 	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	cairo_save(cr);
@@ -707,70 +698,47 @@ hc_draw_check (GtkStyle      *style,
 	ge_cairo_set_color(cr, &hc_style->color_cube.fg[state_type]);
 	cairo_set_line_cap(cr, CAIRO_LINE_CAP_BUTT);
 
-	/* Pixel Alignedness -
-			
-		If even line width, + 1.0 
-		If odd line width,  + 0.5 
-	 */
-	cairo_set_line_width (cr, line_width + ((line_width%2)?1.0:0.5));
+	cairo_set_line_width (cr, line_width);
 
 	/* Stroke Rectangle */
-	ge_cairo_stroke_rectangle (cr, x, y, width, height);
+	ge_cairo_stroke_rectangle (cr, x + line_width/2.0, y + line_width/2.0, width - line_width, height - line_width);
 
 	cairo_restore(cr);
 
 	if ((shadow_type == GTK_SHADOW_IN) || inconsistent)
 	{
-		/* The X is inside the outer line_width */
-		gdouble offset = line_width;
+		cairo_save (cr);
+		/* Clip to the inner area. */
+		cairo_rectangle (cr, x + line_width, y + line_width, width - 2*line_width, height - 2*line_width);
+		cairo_clip (cr);
 
-		/*#warning - MATH && DIAGONALS && PIXEL SNAPPING == PAIN IN MY ARSE*/
-		ge_cairo_set_color(cr, &hc_style->color_cube.fg[state_type]);	
+		ge_cairo_set_color(cr, &hc_style->color_cube.fg[state_type]);
 		
-		/* What should the line width be? not the same as border... 
-			but why this?
-		 */
-		line_width = floor(line_width*3.5); /* ceil(MIN(width,height)/5); */
-
-		/* The X is capped square, 
-				so uh. inset by line_width/2 to center line
-				and.. line_width/2 space? 
-
-				so total inner line_width?
-
-				and + 0.5 if not (line_width - 1) % 2, pixel alignedness, 
-				1 pixel center + even numbers for 45 diagonal?  
-
-				My Head hurts. 
-		 */
-
-		cairo_set_line_cap(cr, CAIRO_LINE_CAP_SQUARE);
+		line_width = ceil(MIN(width,height)/5.0);
 
 		if (inconsistent)
 		{
-			cairo_set_line_width (cr, line_width + 0.5);
+			cairo_set_line_width (cr, line_width);
 
-			cairo_move_to(cr, x + offset, y + floor(height/2.0) + (((line_width - 1) % 2)?0.5:0));
-			cairo_line_to(cr, x + width - offset, y + floor(height/2.0) + (((line_width - 1) % 2)?0.5:0));
+			cairo_move_to(cr, x, y + floor(height/2.0) + (line_width%2)/2.0);
+			cairo_line_to(cr, x + width, y + floor(height/2.0) + (line_width%2)/2.0);
 		}
 		else
 		{
-			/* Again with the + 0.5 if not (line_width - 1) % 2 for pixel alignedness
-					Sort of. I don't think this works for extra large sizes,
-					which means I don't really understand the problem at all....
-			 */
-			cairo_set_line_width (cr, line_width + (((line_width - 1) % 2)?0:0.5));
+			cairo_set_line_width (cr, line_width);
 
 			/* Backward Diagonal */
-			cairo_move_to(cr, x + offset, y + offset);
-			cairo_line_to(cr, x + width - offset, y + height - offset);
+			cairo_move_to(cr, x, y);
+			cairo_line_to(cr, x + width, y + height);
 
 			/* Forward Diagonal */
-			cairo_move_to(cr, x + offset, y + height - offset);
-			cairo_line_to(cr, x + width - offset, y + offset);
+			cairo_move_to(cr, x, y + height);
+			cairo_line_to(cr, x + width, y);
 		}
 
 		cairo_stroke (cr);
+
+		cairo_restore (cr);
 	}
 
 	cairo_destroy(cr);
@@ -914,19 +882,19 @@ hc_draw_layout (GtkStyle        *style,
 		gint             y,
 		PangoLayout     *layout)
 {
-  GdkGC *gc;
-  
-  CHECK_ARGS
+	GdkGC *gc;
 
-  gc = use_text ? style->text_gc[state_type] : style->fg_gc[state_type];
-  
-  if (area)
-    gdk_gc_set_clip_rectangle (gc, area);
+	CHECK_ARGS
 
-  gdk_draw_layout (window, gc, x, y, layout);
+	gc = use_text ? style->text_gc[state_type] : style->fg_gc[state_type];
 
-  if (area)
-    gdk_gc_set_clip_rectangle (gc, NULL);
+	if (area)
+		gdk_gc_set_clip_rectangle (gc, area);
+
+	gdk_draw_layout (window, gc, x, y, layout);
+
+	if (area)
+		gdk_gc_set_clip_rectangle (gc, NULL);
 }
 
 void
@@ -1030,21 +998,21 @@ hc_draw_hline (GtkStyle     *style,
 	       gint          x2,
 	       gint          y)
 {
-  HcStyle *hc_style = HC_STYLE (style);
-  cairo_t *cr;
-  gint line_width;
+	HcStyle *hc_style = HC_STYLE (style);
+	cairo_t *cr;
+	gint line_width;
 
-  CHECK_ARGS
-  
-  cr = ge_gdk_drawable_to_cairo (window, area);
-  
-  line_width = style->ythickness/2;
+	CHECK_ARGS
 
-  do_hc_draw_line (cr, &hc_style->color_cube.fg[state_type], (CHECK_DETAIL(detail, "label"))?1:2*line_width - 1, 
-			x1 + line_width + 2, y + style->ythickness/2 + 0.5, 
-			x2 - line_width - 1, y + style->ythickness/2 + 0.5);     
-  
-  cairo_destroy(cr);
+	cr = ge_gdk_drawable_to_cairo (window, area);
+
+	line_width = style->ythickness/2;
+
+	do_hc_draw_line (cr, &hc_style->color_cube.fg[state_type], (CHECK_DETAIL(detail, "label"))?1:2*line_width - 1, 
+	                 x1 + line_width + 2, y + style->ythickness/2 + 0.5,
+	                 x2 - line_width - 1, y + style->ythickness/2 + 0.5);
+
+	cairo_destroy(cr);
 }
 
 void
@@ -1058,21 +1026,21 @@ hc_draw_vline (GtkStyle     *style,
 	       gint          y2,
 	       gint          x)
 {
-  HcStyle *hc_style = HC_STYLE (style);
-  cairo_t *cr;
-  gint line_width;
+	HcStyle *hc_style = HC_STYLE (style);
+	cairo_t *cr;
+	gint line_width;
 
-  CHECK_ARGS
-  
-  cr = ge_gdk_drawable_to_cairo (window, area);
-  
-  line_width = style->xthickness/2;
+	CHECK_ARGS
 
-  do_hc_draw_line (cr, &hc_style->color_cube.fg[state_type],  (CHECK_DETAIL(detail, "label"))?1:2*line_width - 1, 
-			x + style->xthickness/2 + 0.5, y1, 
-			x + style->xthickness/2 + 0.5, y2);     
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
-  cairo_destroy(cr);
+	line_width = style->xthickness/2;
+
+	do_hc_draw_line (cr, &hc_style->color_cube.fg[state_type],  (CHECK_DETAIL(detail, "label"))?1:2*line_width - 1, 
+	                 x + style->xthickness/2 + 0.5, y1,
+	                 x + style->xthickness/2 + 0.5, y2);
+
+	cairo_destroy(cr);
 }
 
 void
