@@ -46,7 +46,7 @@
 
 #define IF_ROUNDED(style, rounded, otherwise) (GET_ROUNDED_BUTTONS (style) ? rounded : otherwise)
 
-static GtkStyleClass *parent_class;
+G_DEFINE_DYNAMIC_TYPE (IndustrialStyle, industrial_style, GTK_TYPE_STYLE)
 
 static void
 draw_rounded_gradient (cairo_t    *cr,
@@ -907,7 +907,7 @@ real_draw_box (GtkStyle      *style,
 			height -= 1;
 		}
 
-		parent_class->draw_flat_box (style, window, state_type,
+		GTK_STYLE_CLASS (industrial_style_parent_class)->draw_flat_box (style, window, state_type,
 					     shadow_type, area, widget, detail,
 					     x, y, width, height);
 	} else if (CHECK_DETAIL (detail, "slider")
@@ -982,7 +982,7 @@ real_draw_box (GtkStyle      *style,
 				draw_rounded_rect (cr, x, y, width, height, IF_ROUNDED (style, 1.5, 0),
 						   &bevel, &bg, corners);
 			} else {
-				parent_class->draw_flat_box (style, window, state_type, shadow_type, area, widget, detail, x, y, width, height);
+				GTK_STYLE_CLASS (industrial_style_parent_class)->draw_flat_box (style, window, state_type, shadow_type, area, widget, detail, x, y, width, height);
 			}
 		} else if (shadow_type != GTK_SHADOW_NONE) {
 			draw_rounded_rect (cr, x, y, width, height, IF_ROUNDED (style, 1.5, 0),
@@ -1064,7 +1064,7 @@ draw_focus (GtkStyle      *style,
 		return;
 	}
 	
-	parent_class->draw_focus (style, window, state_type, area, widget, detail, x, y, width, height);
+	GTK_STYLE_CLASS (industrial_style_parent_class)->draw_focus (style, window, state_type, area, widget, detail, x, y, width, height);
 }
 
 static void
@@ -1658,4 +1658,68 @@ render_icon (GtkStyle            *style,
 	return stated;
 }
 
-#include "industrial_style_versioned_code.h"
+/* Non-drawing stuff */
+
+void
+industrial_style_register_types (GTypeModule *module)
+{
+	industrial_style_register_type (module);
+}
+
+static void
+industrial_style_copy (GtkStyle * style, GtkStyle * src)
+{
+	IndustrialStyle *industrial_style = INDUSTRIAL_STYLE (style);
+	IndustrialStyle *industrial_src = INDUSTRIAL_STYLE (src);
+
+	industrial_style->contrast = industrial_src->contrast;
+	industrial_style->rounded_buttons = industrial_src->rounded_buttons;
+
+	GTK_STYLE_CLASS (industrial_style_parent_class)->copy (style, src);
+}
+
+static void
+industrial_style_init_from_rc (GtkStyle * style, GtkRcStyle * rc_style)
+{
+	IndustrialStyle *industrial_style = INDUSTRIAL_STYLE (style);
+	GTK_STYLE_CLASS (industrial_style_parent_class)->init_from_rc (style, rc_style);
+
+	industrial_style->contrast = INDUSTRIAL_RC_STYLE (rc_style)->contrast;
+	industrial_style->rounded_buttons = INDUSTRIAL_RC_STYLE (rc_style)->rounded_buttons;
+	industrial_style->hint = INDUSTRIAL_RC_STYLE (rc_style)->hint;
+}
+
+static void
+industrial_style_init (IndustrialStyle * style)
+{
+	style->contrast = 1.0;
+	style->rounded_buttons = TRUE;
+	style->hint = 0;
+}
+
+static void
+industrial_style_class_init (IndustrialStyleClass * klass)
+{
+	GtkStyleClass *style_class = GTK_STYLE_CLASS (klass);
+
+	style_class->copy = industrial_style_copy;
+	style_class->init_from_rc = industrial_style_init_from_rc;
+
+	style_class->draw_focus = draw_focus;
+
+	style_class->draw_handle = draw_handle;
+	style_class->draw_vline = draw_vline;
+	style_class->draw_hline = draw_hline;
+	style_class->draw_slider = draw_slider;
+
+	style_class->draw_check = draw_check;
+	style_class->draw_box = draw_box;
+	style_class->draw_shadow = draw_shadow;
+	style_class->draw_box_gap = draw_box_gap;
+	style_class->draw_shadow_gap = draw_shadow_gap;
+	style_class->draw_extension = draw_extension;
+	style_class->draw_option = draw_option;
+	style_class->render_icon = render_icon;
+}
+
+
